@@ -2,7 +2,7 @@
 
 #include "print_error.h" // inline
 #include "struct_OPArg.h"
-#include "write_log_compare.h" // inline
+#include "write_log_hash_check.h" // inline
 
 #include <fcntl.h>
 #include <sys/mman.h>
@@ -91,11 +91,11 @@ void compare_memcmp(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *
 	{
 		print_error(__func__, __FILE__, __LINE__, cpdd);
 		fprintf(stderr, "ファイルサイズが一致しませんでした、%sを削除します\n", cpinfo->to);
-		write_log_compare(cpinfo, "NULL", "NULL", sdir, cpdd, false);
+		write_log_hash_check(cpinfo, "NULL", "NULL", sdir, cpdd, false);
 		unlink(cpinfo->to);
 		cpinfo->write = false;
 		// falseで初期化しているので要らないはず
-		//cpinfo->compare = false;
+		//cpinfo->hash_check = false;
 	}
 	else
 	{
@@ -170,7 +170,7 @@ void compare_memcmp(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *
 
 						print_error(__func__, __FILE__, __LINE__, cpdd);
 						fprintf(stderr, "ファイルが一致しませんでした、%sを削除します\n", cpinfo->to);
-						write_log_compare(cpinfo, "NULL", "NULL", sdir, cpdd, false);
+						write_log_hash_check(cpinfo, "NULL", "NULL", sdir, cpdd, false);
 						unlink(cpinfo->to);
 						cpinfo->write = false;
 					}
@@ -217,7 +217,7 @@ END:
 
 	if(check == true)
 	{
-		cpinfo->compare = true;
+		cpinfo->hash_check = true;
 
 		if(oparg->V == VERBOS)
 		{
