@@ -1,5 +1,5 @@
-#ifndef INCLUDED_PRINT_ERROR_H
-#define INCLUDED_PRINT_ERROR_H
+#ifndef PRINT_ERROR_H
+#define PRINT_ERROR_H
 
 #include "struct_CPDD.h"
 
