@@ -11,6 +11,10 @@
 #include "struct_CPDD.h"
 #include "struct_CPInfo.h"
 #include "struct_OPArg.h"
+#include "verify_hash.h"
+#include "xmalloc.h"
+
+#include "md5.h"
 
 #include <stdbool.h>
 #include <stdio.h>
@@ -71,6 +75,13 @@
 	}\
 }
 
+struct verify_data
+{
+	md5_state_t *state;
+	void *buffer;
+	int len;
+};
+
 static void *buf[2];
 static off_t from_size_local;
 static off_t written_size[2];
@@ -96,6 +107,7 @@ char *write_now;
 _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd);
 static void * read_thread(void *unknown);
 static void * write_thread(void *unknown);
+static void * do_md5_append(void *tmp);
 
 /*******************************************************************************
 *******************************************************************************/
@@ -103,7 +115,9 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 {
 	static struct stat stat_buf;
 	static _Bool filesystem_check = false;
-	static _Bool filesystem_is_fallocate_support = false;
+	static _Bool fallocate_support = false;
+	static _Bool verify = false;
+	static _Bool verify_option_check = false;
 
 	from_stat = false;
 	from_open = false;
@@ -128,6 +142,16 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 		psize = sysconf(_SC_PAGESIZE);
 	}
 
+	if(verify_option_check == false)
+	{
+		if(oparg->CHECK == V_FIVE)
+		{
+			verify = true;
+		}
+
+		verify_option_check = true;
+	}
+
 	cpinfo->from_size = 0;
 	cpinfo->to_size = 0;
 
@@ -243,7 +267,7 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 				((tofs_tmp[0] == 'o') && (tofs_tmp[1] == 'c') && (tofs_tmp[2] == 'f') && (tofs_tmp[2] == 's') && (tofs_tmp[2] == '2'))
 			)
 			{
-				filesystem_is_fallocate_support = true;
+				fallocate_support = true;
 			}
 		}
 
@@ -257,7 +281,7 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 	 * ext4だと4秒弱で終わるフォルダのコピーが、
 	 * ntfsだと12秒はかかる（何もしないと6秒弱、pwriteだと8秒ほど、ftruncateは何もしない場合とほぼ同じ）。
 	*/
-	if((from_size_local > 0) && (to_open == true) && (filesystem_is_fallocate_support == true))
+	if((from_size_local > 0) && (to_open == true) && (fallocate_support == true))
 	{
 		static int itmp = -1;
 
@@ -281,6 +305,16 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 	// コピー開始
 	if((from_size_local > 0) && (to_open == true))
 	{
+		static md5_state_t state;
+		static md5_byte_t digest[16];
+		static struct verify_data thread_argument;
+		static pthread_t pverify;
+
+		if(verify == true)
+		{
+			md5_init(&state);
+		}
+
 		if(oparg->V == VERBOS)
 		{
 			printf("%s -> %s\n", cpinfo->from, cpinfo->to);
@@ -294,12 +328,22 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 			if(buf[0] != MAP_FAILED)
 			{
 				total_read_local = from_size_local;
+
 				errno = 0;
 				if(madvise(buf[0], from_size_local, MADV_SEQUENTIAL) != 0)
 				{
 					print_error("madvise", __FILE__, __LINE__, cpdd);
 				}
 
+				if(verify == true)
+				{
+					thread_argument.state = &state;
+					thread_argument.buffer = buf[0];
+					thread_argument.len = from_size_local;
+
+					pthread_create(&pverify, NULL, do_md5_append, (void *)&thread_argument);
+				}
+
 				char *tmp = buf[0];
 				const char * const endp = tmp + from_size_local;
 
@@ -315,6 +359,20 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 					total_write_local += written_size[0];
 				}
 
+				if(verify == true)
+				{
+					pthread_join(pverify, NULL);
+					md5_finish(&state, digest);
+					char *hex_output = xmalloc((16 * 2) + 1);
+
+					for(int di = 0; di < 16; ++di)
+					{
+						sprintf(hex_output + di * 2, "%02x", digest[di]);
+					}
+
+					cpinfo->verify_md5 = hex_output;
+				}
+
 				errno = 0;
 				if(munmap(buf[0], from_size_local) != 0)
 				{
@@ -340,7 +398,23 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 			{
 				rbuf_num = 1;
 				wbuf_num = 0;
+
+				if(verify == true)
+				{
+					thread_argument.state = &state;
+					thread_argument.buffer = buf[wbuf_num];
+					thread_argument.len = next_write_size[wbuf_num];
+
+					pthread_create(&pverify, NULL, do_md5_append, (void *)&thread_argument);
+				}
+
 				pthread_create(&t1, NULL, read_thread, (void *)&rbuf_num);
+
+				if(verify == true)
+				{
+					pthread_join(pverify, NULL);
+				}
+
 				pthread_create(&t2, NULL, write_thread, (void *)&wbuf_num);
 				pthread_join(t1, NULL);
 				pthread_join(t2, NULL);
@@ -352,7 +426,23 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 
 				rbuf_num = 0;
 				wbuf_num = 1;
+
+				if(verify == true)
+				{
+					thread_argument.state = &state;
+					thread_argument.buffer = buf[wbuf_num];
+					thread_argument.len = next_write_size[wbuf_num];
+
+					pthread_create(&pverify, NULL, do_md5_append, (void *)&thread_argument);
+				}
+
 				pthread_create(&t1, NULL, read_thread, (void *)&rbuf_num);
+
+				if(verify == true)
+				{
+					pthread_join(pverify, NULL);
+				}
+
 				pthread_create(&t2, NULL, write_thread, (void *)&wbuf_num);
 				pthread_join(t1, NULL);
 				pthread_join(t2, NULL);
@@ -362,6 +452,19 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 					break;
 				}
 			}
+
+			if(verify == true)
+			{
+				md5_finish(&state, digest);
+				char *hex_output = xmalloc((16 * 2) + 1);
+
+				for(int di = 0; di < 16; ++di)
+				{
+					sprintf(hex_output + di * 2, "%02x", digest[di]);
+				}
+
+				cpinfo->verify_md5 = hex_output;
+			}
 		}
 		else
 		{
@@ -396,6 +499,15 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 						print_error("madvise", __FILE__, __LINE__, cpdd);
 					}
 
+					if(verify == true)
+					{
+						thread_argument.state = &state;
+						thread_argument.buffer = buf[0];
+						thread_argument.len = read_size;
+
+						pthread_create(&pverify, NULL, do_md5_append, (void *)&thread_argument);
+					}
+
 					char *tmp = buf[0];
 					const char * const endp = tmp + read_size;
 
@@ -418,6 +530,11 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 						total_write_local += written_size[0];
 					}
 
+					if(verify == true)
+					{
+						pthread_join(pverify, NULL);
+					}
+
 					errno = 0;
 					if(munmap(buf[0], read_size) != 0)
 					{
@@ -437,6 +554,18 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 			}
 LOOP_END:
 ;
+			if(verify == true)
+			{
+				md5_finish(&state, digest);
+				char *hex_output = xmalloc((16 * 2) + 1);
+
+				for(int di = 0; di < 16; ++di)
+				{
+					sprintf(hex_output + di * 2, "%02x", digest[di]);
+				}
+
+				cpinfo->verify_md5 = hex_output;
+			}
 		}
 
 		/*
@@ -461,6 +590,13 @@ LOOP_END:
 			}
 		}
 	}
+	else if((from_size_local == 0) && (to_open == true))
+	{
+		if(ftruncate(ito, 0) == -1)
+		{
+			print_error("ftruncate", __FILE__, __LINE__, cpdd);
+		}
+	}
 
 	if((from_stat == true) && (to_open == true))
 	{
@@ -470,7 +606,7 @@ LOOP_END:
 /*
  * fdatasyncするようにしたら、30倍遅くなった。
 
-	if((oparg->C != NOT) && (filesystem_is_fallocate_support == true))
+	if((oparg->CHECK != NOT) && (fallocate_support == true))
 	{
 		if(fdatasync(ito) == -1)
 		{
@@ -519,9 +655,9 @@ LOOP_END:
 
 	write_now = NULL;
 
-	if(oparg->COMPARE_MODE == BEFORE)
+	if(oparg->CHECK_MODE == BEFORE)
 	{
-		switch(oparg->C)
+		switch(oparg->CHECK)
 		{
 		case ONE:
 			HASH_CHECK
@@ -544,8 +680,23 @@ LOOP_END:
 			}
 			break;
 
+		case V_FIVE:
+			if(cpinfo->verify_md5 != NULL)
+			{
+				verify_hash(oparg, cpinfo, sdir, cpdd);
+			}
+			else
+			{
+				if(from_size_local != 0)
+				{
+					fprintf(stderr, "ベリファイをスキップします\n");
+					fprintf(stderr, "to : %s\n", cpinfo->to);
+				}
+			}
+			break;
+
 		default:
-			fprintf(stderr, "コンペアオプションが不正です");
+			fprintf(stderr, "コンペアオプションが不正です\n");
 			break;
 		}
 
@@ -666,3 +817,18 @@ static void * write_thread(void *unknown)
 
 	return NULL;
 }
+
+/*******************************************************************************
+ * ベリファイ用
+*******************************************************************************/
+static void * do_md5_append(void *tmp)
+{
+	struct verify_data *tmp_vd = tmp;
+	md5_state_t *state = tmp_vd->state;
+	md5_byte_t *buffer = tmp_vd->buffer;
+	int len = tmp_vd->len;
+
+	md5_append(state, buffer, len);
+
+	return NULL;
+}
