@@ -13,6 +13,7 @@
 #include "struct_DPath.h"
 #include "struct_OPArg.h"
 #include "struct_SData.h"
+#include "verify_hash.h"
 #include "write_conf.h"
 
 #include <stdbool.h>
@@ -20,7 +21,7 @@
 #include <stdlib.h>
 
 // 関数プロトタイプ
-static inline void do_compare_two(const OPArg *oparg, const VList *file_list, const SDir *sdir, CPDD *cpdd) __attribute__((always_inline));
+static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_list, const SDir *sdir, CPDD *cpdd) __attribute__((always_inline));
 static inline void delete_from(const OPArg *oparg, const VList *file_list, CPDD *cpdd) __attribute__((always_inline));
 
 /*******************************************************************************
@@ -57,6 +58,11 @@ int main(int argc, char **argv)
 			help();
 			return EXIT_SUCCESS;
 		}
+		else
+		{
+			fprintf(stderr, "引数が足りません\n");
+			return EXIT_FAILURE;
+		}
 	}
 
 	OPArg *oparg = read_conf(sdir);
@@ -79,13 +85,13 @@ int main(int argc, char **argv)
 		puts("コピーを完了しました...");
 	}
 
-	if((file_list != NULL) && (oparg->COMPARE_MODE == AFTER))
+	if((file_list != NULL) && (oparg->CHECK_MODE == AFTER))
 	{
-		puts("コンペアを開始します...");
+		puts("ハッシュ値のチェックを開始します...");
 
-		do_compare_two(oparg, file_list, sdir, cpdd);
+		do_compare_verify_two(oparg, file_list, sdir, cpdd);
 
-		puts("コンペアを完了しました...");
+		puts("ハッシュ値のチェックを完了しました...");
 	}
 
 	if(oparg->M == MOVE)
@@ -142,7 +148,7 @@ int main(int argc, char **argv)
 	}\
 }
 
-static inline void do_compare_two(const OPArg *oparg, const VList *file_list, const SDir *sdir, CPDD *cpdd)
+static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_list, const SDir *sdir, CPDD *cpdd)
 {
 	/*
 	* キャストしないと警告が出る
@@ -156,7 +162,7 @@ static inline void do_compare_two(const OPArg *oparg, const VList *file_list, co
 
 		if(cpinfo->from_type == REGULAR)
 		{
-			switch(oparg->C)
+			switch(oparg->CHECK)
 			{
 			case ONE:
 				HASH_CHECK
@@ -179,6 +185,21 @@ static inline void do_compare_two(const OPArg *oparg, const VList *file_list, co
 				}
 				break;
 
+			case V_FIVE:
+				if(cpinfo->verify_md5 != NULL)
+				{
+					verify_hash(oparg, cpinfo, sdir, cpdd);
+				}
+				else
+				{
+					if(cpinfo->from_size != 0)
+					{
+						fprintf(stderr, "ベリファイをスキップします\n");
+						fprintf(stderr, "to : %s\n", cpinfo->to);
+					}
+				}
+				break;
+
 			default:
 				fprintf(stderr, "コンペアオプションが不正です");
 				break;
@@ -227,9 +248,9 @@ static inline void delete_from(const OPArg *oparg, const VList *file_list, CPDD
 		switch(cpinfo->from_type)
 		{
 		case REGULAR:
-			if(oparg->C != NOT)
+			if(oparg->CHECK != NOT)
 			{
-				if(cpinfo->compare == true)
+				if(cpinfo->hash_check == true)
 				{
 					FILE_REMOVE
 				}
