@@ -1,9 +1,9 @@
-#ifndef INCLUDED_STRUCT_DPATH_H
-#define INCLUDED_STRUCT_DPATH_H
+#ifndef STRUCT_DRIVE_PATH_H
+#define STRUCT_DRIVE_PATH_H
 
 // ドライブのデバイスファイルとマウントポイントのパスと、
 // ファイルシステムの種類を入れる構造体
-typedef struct system_drive_path
+typedef struct drive_path
 {
 	char *device;
 	char *mount_point;
