@@ -8,6 +8,7 @@ typedef enum option_flag
 	ONE, /* コンペア（SHA-1） */
 	FIVE, /* コンペア（MD5） */
 	MEMCMP, /* コンペア（memcmp） */
+	V_FIVE, /* ベリファイ（MD5） */
 	BEFORE,
 	AFTER,
 	LOG, /* コンペアログ保存 */
@@ -15,7 +16,7 @@ typedef enum option_flag
 	SIZE_OR_TIME,
 	NEW_TIME,
 	OVERWRITE,
-	NO_OVERWRITE, /* 0 */
+	NO_OVERWRITE, /* -0 */
 
 	DRIVE_AUTO,
 	DRIVE_SAME,
@@ -31,10 +32,12 @@ typedef enum option_flag
 
 typedef struct option_and_argument
 {
-	off_t buffer_size;
-	off_t buffer_size_thread;
-	enum option_flag C;
-	enum option_flag COMPARE_MODE; /* 1 or 2 */
+	// MD5ライブラリの引数がintなので、バッファサイズもintが上限
+	int buffer_size;
+	int buffer_size_thread;
+
+	enum option_flag CHECK;
+	enum option_flag CHECK_MODE; /* 1 or 2 */
 	enum option_flag WRITE_MODE; /* 1 or 2 or 3 or 0*/
 	enum option_flag THREAD_MODE; /* 1 or 2 or 0 */
 	enum option_flag I;
