@@ -1,5 +1,5 @@
-#ifndef INCLUDED_STRUCT_VLIST_H
-#define INCLUDED_STRUCT_VLIST_H
+#ifndef STRUCT_VOID_LIST_H
+#define STRUCT_VOID_LIST_H
 
 // 双方向リスト
 typedef struct void_list
