@@ -33,58 +33,45 @@ void write_conf(const SDir *sdir)
 
 	char stdin_buf[INPUT_LEN];
 	char compare = '@';
-	char COMPARE_MODE = '@';
+	char hash_check_mode = '@';
 	int b_op = 0;
 	char i_op = '@';
 	char l_op = '@';
 	char m_op = '@';
+	char r_op = '@';
 	char t_op = '@';
-	char THREAD_MODE = '@';
+	char thread_mode = '@';
 	char v_op = '@';
 	char w_op = '@';
-	char WRITE_MODE = '@';
+	char write_mode = '@';
 
 	puts("設定の変更を行います");
 
 	{
 		puts("");
-		puts("ファイルコピー後にコンペアを行いますか?");
+		puts("ファイルコピー後にベリファイを行いますか?");
 		printf("(y / n) :");
 
 		INPUT_CHECK_CLEAN
 
 		if(stdin_buf[0] == 'y')
 		{
+			r_op = stdin_buf[0];
+
 			puts("");
-			puts("コンペアオプションを選んでください");
-			puts("1 : SHA-1");
-			puts("5 : MD5");
-			puts("c : 単純比較");
-			printf("(1 / 5 / c) :");
+			puts("ベリファイモードを選んでください");
+			puts("1 : コピー直後にベリファイ");
+			puts("2 : 全コピー終了後に一括ベリファイ");
+			printf("(1 / 2) :");
 
 			INPUT_CHECK_CLEAN
 
-			if((stdin_buf[0] == '1') || (stdin_buf[0] == '5') || (stdin_buf[0] == 'c'))
+			if((stdin_buf[0] == '1') || (stdin_buf[0] == '2'))
 			{
-				compare = stdin_buf[0];
+				hash_check_mode = stdin_buf[0];
+
 				puts("");
-				puts("コンペアモードを選んでください");
-				puts("1 : コピー直後にコンペア");
-				puts("2 : 全コピー終了後に一括コンペア");
-				printf("(1 / 2) :");
-
-				INPUT_CHECK_CLEAN
-
-				if((stdin_buf[0] == '1') || (stdin_buf[0] == '2'))
-				{
-					COMPARE_MODE = stdin_buf[0];
-				}
-			}
-
-			if((compare == '1') || (compare == '5'))
-			{
-				puts("");
-				puts("コンペアのログを保存しますか?");
+				puts("ベリファイのログを保存しますか?");
 				printf("(y / n) :");
 
 				INPUT_CHECK_CLEAN
@@ -94,6 +81,65 @@ void write_conf(const SDir *sdir)
 					l_op = stdin_buf[0];
 				}
 			}
+			else
+			{
+				r_op = '@';
+			}
+		}
+		else
+		{
+			puts("");
+			puts("ファイルコピー後にコンペアを行いますか?");
+			printf("(y / n) :");
+
+			INPUT_CHECK_CLEAN
+
+			if(stdin_buf[0] == 'y')
+			{
+				puts("");
+				puts("コンペアオプションを選んでください");
+				puts("1 : SHA-1");
+				puts("5 : MD5");
+				puts("c : 単純比較");
+				printf("(1 / 5 / c) :");
+
+				INPUT_CHECK_CLEAN
+
+				if((stdin_buf[0] == '1') || (stdin_buf[0] == '5') || (stdin_buf[0] == 'c'))
+				{
+					compare = stdin_buf[0];
+					puts("");
+					puts("コンペアモードを選んでください");
+					puts("1 : コピー直後にコンペア");
+					puts("2 : 全コピー終了後に一括コンペア");
+					printf("(1 / 2) :");
+
+					INPUT_CHECK_CLEAN
+
+					if((stdin_buf[0] == '1') || (stdin_buf[0] == '2'))
+					{
+						hash_check_mode = stdin_buf[0];
+					}
+					else
+					{
+						compare = '@';
+					}
+				}
+
+				if((compare == '1') || (compare == '5'))
+				{
+					puts("");
+					puts("コンペアのログを保存しますか?");
+					printf("(y / n) :");
+
+					INPUT_CHECK_CLEAN
+
+					if(stdin_buf[0] == 'y')
+					{
+						l_op = stdin_buf[0];
+					}
+				}
+			}
 		}
 	}
 
@@ -106,7 +152,7 @@ void write_conf(const SDir *sdir)
 
 		if(stdin_buf[0] == 'y')
 		{
-			puts("数値を入力してください(初期値は64です)");
+			puts("数値を入力してください(初期値は32です)");
 			printf(" :");
 
 			INPUT_CHECK_CLEAN
@@ -116,7 +162,7 @@ void write_conf(const SDir *sdir)
 	
 			if(b_op < 0)
 			{
-				b_op = 0;
+				b_op = 2;
 			}
 		}
 	}
@@ -156,7 +202,11 @@ void write_conf(const SDir *sdir)
 
 				if((stdin_buf[0] == '1') || (stdin_buf[0] == '2') || (stdin_buf[0] == '3') || (stdin_buf[0] == '0'))
 				{
-					WRITE_MODE = stdin_buf[0];
+					write_mode = stdin_buf[0];
+				}
+				else
+				{
+					w_op = '@';
 				}
 			}
 		}
@@ -177,7 +227,7 @@ void write_conf(const SDir *sdir)
 
 	{
 		puts("");
-		puts("スレッドモードを指定しますか?");
+		puts("スレッドモードを指定しますか? (初期設定は自動判別)");
 		printf("(y / n) :");
 
 		INPUT_CHECK_CLEAN
@@ -197,7 +247,11 @@ void write_conf(const SDir *sdir)
 
 			if((stdin_buf[0] == '1') || (stdin_buf[0] == '2') || (stdin_buf[0] == '0'))
 			{
-				THREAD_MODE = stdin_buf[0];
+				thread_mode = stdin_buf[0];
+			}
+			else
+			{
+				t_op = '@';
 			}
 		}
 	}
@@ -217,10 +271,13 @@ void write_conf(const SDir *sdir)
 
 	// 設定をファイルに保存する
 	if(
-		(COMPARE_MODE != '@') ||
+		(hash_check_mode != '@') ||
 		(b_op > 0) ||
 		(i_op != '@') ||
-		(WRITE_MODE != '@') ||
+		(write_mode != '@') ||
+		(m_op != '@') ||
+		(r_op != '@') ||
+		(thread_mode != '@') ||
 		(v_op != '@')
 	)
 	{
@@ -265,7 +322,7 @@ void write_conf(const SDir *sdir)
 
 			puts(" ");
 
-			if(COMPARE_MODE != '@')
+			if(compare != '@')
 			{
 				{
 					if(fputc(compare, config) == EOF)
@@ -276,7 +333,7 @@ void write_conf(const SDir *sdir)
 					{
 						write_error("fputs");
 					}
-					else if(fputc(COMPARE_MODE, config) == EOF)
+					else if(fputc(hash_check_mode, config) == EOF)
 					{
 						write_error("fputc");
 					}
@@ -299,7 +356,31 @@ void write_conf(const SDir *sdir)
 					puts("コンペアタイプ : memcmp");
 				}
 
-				printf("コンペアモード : %c\n", COMPARE_MODE);
+				printf("コンペアモード : %c\n", hash_check_mode);
+			}
+
+			if(r_op != '@')
+			{
+				{
+					if(fputc('r', config) == EOF)
+					{
+						write_error("fputc");
+					}
+					else if(fputs(",", config) == EOF)
+					{
+						write_error("fputs");
+					}
+					else if(fputc(hash_check_mode, config) == EOF)
+					{
+						write_error("fputc");
+					}
+					else if(fputs("\n", config) == EOF)
+					{
+						write_error("fputs");
+					}
+				}
+
+				printf("ベリファイモード : %c\n", hash_check_mode);
 			}
 
 			if(b_op > 0)
@@ -335,7 +416,7 @@ void write_conf(const SDir *sdir)
 				puts("上書き確認する");
 			}
 
-			if(WRITE_MODE != '@')
+			if(write_mode != '@')
 			{
 				{
 					if(fputs("w", config) == EOF)
@@ -346,7 +427,7 @@ void write_conf(const SDir *sdir)
 					{
 						write_error("fputs");
 					}
-					else if(fputc(WRITE_MODE, config) == EOF)
+					else if(fputc(write_mode, config) == EOF)
 					{
 						write_error("fputc");
 					}
@@ -356,7 +437,7 @@ void write_conf(const SDir *sdir)
 					}
 				}
 
-				printf("上書きモード   : %c\n", WRITE_MODE);
+				printf("上書きモード   : %c\n", write_mode);
 			}
 
 			if(l_op != '@')
@@ -389,7 +470,7 @@ void write_conf(const SDir *sdir)
 				puts("移動モード");
 			}
 
-			if(THREAD_MODE != '@')
+			if(thread_mode != '@')
 			{
 				{
 					if(fputs("t", config) == EOF)
@@ -400,7 +481,7 @@ void write_conf(const SDir *sdir)
 					{
 						write_error("fputs");
 					}
-					else if(fputc(THREAD_MODE, config) == EOF)
+					else if(fputc(thread_mode, config) == EOF)
 					{
 						write_error("fputc");
 					}
@@ -410,7 +491,7 @@ void write_conf(const SDir *sdir)
 					}
 				}
 
-				printf("スレッドモード : %c\n", THREAD_MODE);
+				printf("スレッドモード : %c\n", thread_mode);
 			}
 
 			if(v_op != '@')
